@@ -77,10 +77,8 @@ class Source:
     Helper.check_emits("source", self._emits, self._app._streams)
 
   def run_operation(self):
-    host = self._app._options.get("host", None)
-    port = self._app._options.get("port", None)
-    controller = Controller(host, port, self._emits)
-
+    
+    controller = Controller(self._emits, self._app._options)
     controller.get_pidDir()
 
     while True:
